## START: Set by rpmautospec
## (rpmautospec version 0.7.3)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 3;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

# Try to download data, so a few are disabled.
# We test these in mock using --with=net_tests --enable-network
%bcond net_tests 0

%global forgeurl  https://github.com/NeuralEnsemble/elephant/

Name:       python-elephant
Version:    1.1.1
Release:    %autorelease
Summary:    Analysis of electrophysiology data, using Neo data structures

%forgemeta

# SPDX
# elephant/spade_src is MIT licensed
License:    BSD-3-Clause AND MIT
URL:        http://neuralensemble.org/elephant
Source0:    %forgesource

# All changes are here
# https://github.com/sanjayankur31/elephant/tree/fedora-0.11.1
Patch0:     0001-use-fedora-build-flags.patch

# python-pyedflib does not support s390x, so the complete dep tree needs to also exclude it
# https://src.fedoraproject.org/rpms/python-pyedflib/blob/rawhide/f/python-pyedflib.spec
ExcludeArch: s390x

# Stop building for i686 (leaf package)
# https://fedoraproject.org/wiki/Changes/EncourageI686LeafRemoval
ExcludeArch: %{ix86}

# Includes a modified copy of fim, so we cannot use the system copy of pyfim.
# https://github.com/NeuralEnsemble/elephant/issues/471#issuecomment-1098908479

BuildRequires:  git-core
BuildRequires:  gcc-c++
BuildRequires:  python3-devel

%global _description %{expand:
Elephant (Electrophysiology Analysis Toolkit) is an open-source,
community centered library for the analysis of electrophysiological
data in the Python programming language. The focus of Elephant is on
generic analysis functions for spike train data and time series
recordings from electrodes, such as the local field potentials (LFP) or
intracellular voltages. In addition to providing a common platform for
analysis code from different laboratories, the Elephant project aims to
provide a consistent and homogeneous analysis framework that is built
on a modular foundation. Elephant is the direct successor to Neurotools
and maintains ties to complementary projects such as OpenElectrophy and
spykeviewer.

Elephant was developed in part in the Human Brain Project, funded from
the European Union’s Horizon 2020 Framework Programme for Research and
Innovation under Specific Grant Agreements No. 720270, No. 785907 and
No. 945539 (Human Brain Project SGA1, SGA2, and SGA3).}

%description %_description


%package -n     python3-elephant
Summary:        %{summary}

%description -n python3-elephant %_description


%prep
%forgeautosetup -S git

# Loosen scipy version cap
# https://github.com/NeuralEnsemble/elephant/issues/47
sed -i 's/scipy.*/scipy/' requirements/requirements.txt

for lib in $(find . -type f -name "*.py"); do
 sed '1{\@^#!/usr/bin/env python@d}' $lib > $lib.new &&
 touch -r $lib $lib.new &&
 mv $lib.new $lib
done

# collect all test requirements in one file
echo >> requirements/requirements-tests.txt
cat requirements/requirements-extras.txt >> requirements/requirements-tests.txt

# Drop `nixio` test requirement.
sed  -r -i '/nixio/d' requirements/requirements-tests.txt


%generate_buildrequires
%pyproject_buildrequires -r requirements/requirements-tests.txt


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files -l elephant


%check
# One test fails generally: reported upstream
# https://github.com/NeuralEnsemble/elephant/issues/410
# Fixed upstream (but Fedora dropped armv7hl support in F37)

# fails on aarch64
# reported upstream: https://github.com/NeuralEnsemble/elephant/issues/479
%ifarch %{arm64}
k="${k:-}${k:+ and }not test_welch_psd_multidim_input"
k="${k:-}${k:+ and }not test_welch_cohere_multidim_input"
k="${k:-}${k:+ and }not test_multitaper_cohere_perfect_cohere"
%endif

# fails on ppc64le
%ifarch %{power64}
k="${k:-}${k:+ and }not test_multitaper_cohere_perfect_cohere"
%endif

%if %{without net_tests}
# Disable tests that download bits
k="${k:-}${k:+ and }not test_repr"
k="${k:-}${k:+ and }not test__UE_surrogate"
k="${k:-}${k:+ and }not test_spike_contrast_with_Izhikevich_network_auto"
k="${k:-}${k:+ and }not test_Riehle_et_al_97_UE"
k="${k:-}${k:+ and }not test_multitaper_psd_against_nitime"
k="${k:-}${k:+ and }not test_WPLI_"
k="${k:-}${k:+ and }not test_victor_purpura_matlab_comparison_"
k="${k:-}${k:+ and }not test_pairwise_spectral_granger"
k="${k:-}${k:+ and }not test_total_spiking_probability_edges"
%endif

# Requires `nixio` in addition to network.
k="${k:-}${k:+ and }not test_sttc_validation_test"

%pytest -v ${k+-k }"${k-}"


%files -n python3-elephant -f %{pyproject_files}
%license elephant/spade_src/LICENSE


%changelog
## START: Generated by rpmautospec
* Mon Nov 11 2024 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 1.1.1-2
- fix: remove unused patch (fixes rh#2322167)

* Mon Oct 28 2024 Packit <hello@packit.dev> - 1.1.1-1
- Update to 1.1.1 upstream release
- Resolves: rhbz#2322167

* Sat Aug 17 2024 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 1.1.0-6
- fix: re-skip aarch64 test (fixes rh#2291685, rh#2301142)

* Sat Aug 17 2024 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 1.1.0-5
- fix FTBFS (fixes rh#2291685, rh#2301142)

* Fri Jul 19 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Sat Jun 15 2024 Python Maint <python-maint@redhat.com> - 1.1.0-3
- Rebuilt for Python 3.13

* Thu Apr 11 2024 Sandro <devel@penguinpee.nl> - 1.1.0-2
- Disable failing test (needs network)

* Wed Apr 10 2024 Packit <hello@packit.dev> - 1.1.0-1
- Update to 1.1.0 upstream release
- Resolves: rhbz#2274374

* Wed Mar 13 2024 Sandro <devel@penguinpee.nl> - 1.0.0-14
- Fix Packit config

* Fri Jan 26 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.0-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Mon Jan 22 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.0-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Tue Jan 09 2024 Sandro <devel@penguinpee.nl> - 1.0.0-11
- Add Packit config

* Mon Jan 08 2024 Sandro <devel@penguinpee.nl> - 1.0.0-10
- Re-enable parallel test (no longer fails)

* Mon Jan 08 2024 Sandro <devel@penguinpee.nl> - 1.0.0-9
- Stop building for i686 (leaf package)

* Mon Jan 08 2024 Sandro <devel@penguinpee.nl> - 1.0.0-8
- Assert existence of license file
- Update License: tag (dual license)

* Mon Jan 08 2024 Sandro <devel@penguinpee.nl> - 1.0.0-7
- Whitespace changes
- Seperate sections by two empty line (for readability)

* Mon Jan 08 2024 Sandro <devel@penguinpee.nl> - 1.0.0-6
- Use human friendly bcond notation

* Mon Jan 08 2024 Sandro <devel@penguinpee.nl> - 1.0.0-5
- Migrate to SPDX license

* Mon Jan 08 2024 Sandro <devel@penguinpee.nl> - 1.0.0-4
- Update summary and description (following upstream)

* Mon Jan 08 2024 Sandro <devel@penguinpee.nl> - 1.0.0-3
- Drop pypi_name (unused)

* Mon Jan 08 2024 Sandro <devel@penguinpee.nl> - 1.0.0-2
- Amend list of tests requiring network
- Refactor test exceptions (one per line)

* Mon Jan 08 2024 Sandro <devel@penguinpee.nl> - 1.0.0-1
- Update to 1.0.0 (RHBZ#2222778)

* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 0.12.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Wed Jul 12 2023 Python Maint <python-maint@redhat.com> - 0.12.0-3
- Rebuilt for Python 3.12

* Mon Feb 27 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.12.0-2
- fix: deselect failing tests

* Mon Feb 27 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.12.0-1
- feat: update to 0.12.0 (fixes rhbz#2137931, fixes rhbz#2173307)

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 0.11.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Sun Oct 09 2022 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.11.1-3
- feat: exclude s390x

* Fri Sep 09 2022 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.11.1-2
- chore: add comment about upstream fix

* Fri Sep 09 2022 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.11.1-1
- feat: update to 0.11.1

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.11.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Jul 04 2022 Python Maint <python-maint@redhat.com> - 0.11.0-2
- Rebuilt for Python 3.11

* Thu Apr 21 2022 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.11.0-1
- feat: update to 0.11.0 (Fixes rhbz#2070262)

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.10.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.10.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 0.10.0-3
- Rebuilt for Python 3.10

* Fri Mar 12 2021 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.10.0-2
- Add py_provides macro for F32

* Thu Mar 11 2021 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.10.0-1
- Update to new release
- Enable all non-network dependent tests
- File bug for failing tests
- Update fim tweak: no longer required in the test file
- include statsmodels dependency

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.6.4-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.6.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 0.6.4-3
- Rebuilt for Python 3.9

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.6.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Mon Dec 23 2019 Luis Bazan <lbazan@fedoraproject.org> - 0.6.4-1
- New upstream version

* Mon Aug 19 2019 Miro Hrončok <mhroncok@redhat.com> - 0.6.2-5
- Rebuilt for Python 3.8

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.6.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Fri Jun 14 2019 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.6.2-3
- Use pyfim which is 10 times faster than the python fast_fca according to docs
- Patch out bits that try to download fim
- Version neo requirements

* Fri Jun 14 2019 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.6.2-2
- Report issues upstream and add links to spec file

* Tue Jun 11 2019 Luis Bazan <lbazan@fedoraproject.org> - 0.6.2-2
- Fix comment #11 BZ#1651824

* Fri Jun 07 2019 Luis Bazan <lbazan@fedoraproject.org> - 0.6.2-1
- Initial package.

## END: Generated by rpmautospec
